@@ -8,7 +8,7 @@
 # This file uses Getopt::Long for simple management of command line arguments,
 # and Term::AnsiColor for clearer console output.
 
-#USAGE perl doScores.pl -tsvfile='yourfile.06out' -intactfile='yourfile.direct.02'
+#USAGE perl doScores.pl -tsvfile="yourfile.06out" -intactfile="yourfile.direct.02"
 
 use strict;
 use warnings;
@@ -17,6 +17,8 @@ use Term::ANSIColor;
 use Bio::Homology::InterologWalk;
 use Carp qw(croak);
 
+my $start_run = time;
+
 my $RC;
 my $in_path;
 my $out_path;
@@ -35,11 +37,11 @@ GetOptions(
 
 #filenames and files===============================================
 if( !$infilename ){
-    print "\nUSAGE perl doScores.pl -tsvfile='<yourfile>.06out' -intactfile='<yourfile>.direct.02'\n";
+    print "\nUSAGE perl doScores.pl -tsvfile=\"<yourfile>.06out\" -intactfile=\"<yourfile>.direct.02\"\n";
     exit;
 }
 if(!$intactfile){
-    print "\nUSAGE perl doScores.pl -tsvfile='<yourfile>.06out' -intactfile='<yourfile>.direct.02'\n";
+    print "\nUSAGE perl doScores.pl -tsvfile=\"<yourfile>.06out\" -intactfile=\"<yourfile>.direct.02\"\n";
     exit;
 }
 
@@ -67,13 +69,14 @@ $score_path = $work_dir . $score_filename;
 #Computing Mean Multiple taxa score
 #==================================================================
 #WARNING: this might take a long time
-$m_mtaxa = Bio::Homology::InterologWalk::Scores::compute_multiple_taxa_mean(
-                                                            ds_size   => 10,          
-                                                            #size: ideally it should be comparable to the dataset size
-                                                            ds_number => 3,           
-                                                            #max is currently 7, equal to the number of taxa with significant amount of data
-                                                            datadir   => $work_dir
-                                                            );
+#$m_mtaxa = Bio::Homology::InterologWalk::Scores::compute_multiple_taxa_mean(
+#                                                            ds_size   => 15,          
+#                                                            #size: ideally it should be comparable to the dataset size
+#                                                            ds_number => 2,           
+#                                                            #max is currently 7, equal to the number of taxa with significant amount of data
+#                                                            datadir   => $work_dir
+#                                                            );
+$m_mtaxa = 1;
 if ( !$m_mtaxa ) {
     print "There were errors. Stopping..\n";
     exit;
@@ -92,11 +95,10 @@ if ( !$onto_graph ) {
 my ( $m_em, $m_it, $m_dm, $m_mdm ) =
   Bio::Homology::InterologWalk::Scores::get_mean_scores( $intact_path, $onto_graph );
 
-
 #4) compute actual scores
 print colored ( "Computing putative interaction scores...", 'green' ), "\n";
-my $start_run = time;
-$RC = Bio::Homology::InterologWalk::Scores::compute_scores(
+
+my $RC_0 = Bio::Homology::InterologWalk::Scores::compute_confidence_score(
                                              input_path        => $in_path,
                                              score_path        => $score_path,
                                              output_path       => $out_path,
@@ -107,10 +109,48 @@ $RC = Bio::Homology::InterologWalk::Scores::compute_scores(
                                              meanscore_me_dm   => $m_mdm,
                                              meanscore_me_taxa => $m_mtaxa
 );
-if ( !$RC ) {
+if ( !$RC_0 ) {
     print "There were errors. Stopping..\n" ;
     exit;
 }
+
+
+$in_path = $out_path;
+$out_filename = $infilename . $Bio::Homology::InterologWalk::OUTEX8;
+$out_path = $work_dir . $out_filename;
+$score_filename = $infilename . '.cons_hist';
+$score_path = $work_dir . $score_filename;
+
+#set up url
+my $intact_url = "http://www.ebi.ac.uk/Tools/webservices/psicquic/intact/webservices/current/";
+
+#-------------------------------------------------
+#EXPERIMENTAL - 
+#for testing purposes only
+#PLEASE REMOVE if performances severely affected,
+#or set "max_nodes" to a smaller value
+#-------------------------------------------------
+#5) compute Conservation Score, stored in separate column
+print "\n\n";
+print colored ( "Computing PPI conservation score...", 'green' ), "\n";
+my $RC_1 = Bio::Homology::InterologWalk::Scores::compute_conservation_score(
+                                             input_path        => $in_path,
+                                             score_path        => $score_path,
+                                             output_path       => $out_path,
+                                             url               => $intact_url,
+                                             max_nodes         => 25 
+                                             #keep max_nodes to a reasonable number, 
+                                             #depending on the power of your machine 
+                                             #(eg. < 30 on a reasonably fast dual core workstation)
+                                             );
+if ( !$RC_1 ) {
+    print "There were errors. Stopping..\n" ;
+    exit;
+}
+#------------
+#/EXPERIMENTAL
+#------------
+
 my $end_run  = time;
 my $run_time = $end_run - $start_run;
 print "\n\n*FINISHED* Job took $run_time seconds\n";
