@@ -28,7 +28,7 @@ GetOptions('filename=s'=>\$infilename,
            'sourceorg=s'=>\$sourceorg);
 #filenames and files===============================================
 if(!$infilename){
-     $infilename = 'mmus_test.txt';
+     $infilename = 'schizophreniamouselist.txt';
      print "getDirectInteractions.pl: No filename specified..Trying default..$infilename\n";
 }else{
      print "getDirectInteractions.pl: using input file: $infilename\n";
@@ -68,12 +68,12 @@ my $url = "http://www.ebi.ac.uk/Tools/webservices/psicquic/intact/webservices/cu
 my $start_run = time();
 print "\n\n", colored ("Getting Interactions from Intact...", 'green'), "\n\n";
 my $RC1 = Bio::Homology::InterologWalk::Direct::get_direct_interactions(
-                                                    registry        => $registry,
+                                                    registry            => $registry,
                                                     source_org          => $sourceorg,
                                                     input_path          => $in_path,
                                                     output_path         => $out_path,
                                                     url                 => $url,
-                                                    #check_ids          => 1,     
+                                                    check_ids           => 1,     
                                                     #the following are used to build a more complex query and filter out low quality interactions
                                                     no_spoke            => 1, #
                                                     exp_only            => 1, #
